==> kubernetes-model-extensions-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/RollingUpdateDeploymentFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.model.IntOrString;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RollingUpdateDeploymentFluentImpl<A extends RollingUpdateDeploymentFluent<A>> extends BaseFluent<A> implements RollingUpdateDeploymentFluent<A>{
  public RollingUpdateDeploymentFluentImpl() {
  }
  public RollingUpdateDeploymentFluentImpl(RollingUpdateDeployment instance) {
    this.withMaxSurge(instance.getMaxSurge()); 
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private IntOrStringBuilder maxSurge;
  private IntOrStringBuilder maxUnavailable;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMaxSurge instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxSurge() {
    return this.maxSurge!=null ?this.maxSurge.build():null;
  }
  public IntOrString buildMaxSurge() {
    return this.maxSurge!=null ?this.maxSurge.build():null;
  }
  public A withMaxSurge(IntOrString maxSurge) {
    _visitables.get("maxSurge").remove(this.maxSurge);
    if (maxSurge!=null){ this.maxSurge= new IntOrStringBuilder(maxSurge); _visitables.get("maxSurge").add(this.maxSurge);} else { this.maxSurge = null; _visitables.get("maxSurge").remove(this.maxSurge); } return (A) this;
  }
  public Boolean hasMaxSurge() {
    return this.maxSurge != null;
  }
  public A withNewMaxSurge(Object value) {
    return (A)withMaxSurge(new IntOrString(value));
  }
  public RollingUpdateDeploymentFluent.MaxSurgeNested<A> withNewMaxSurge() {
    return new RollingUpdateDeploymentFluentImpl.MaxSurgeNestedImpl();
  }
  public RollingUpdateDeploymentFluent.MaxSurgeNested<A> withNewMaxSurgeLike(IntOrString item) {
    return new RollingUpdateDeploymentFluentImpl.MaxSurgeNestedImpl(item);
  }
  public RollingUpdateDeploymentFluent.MaxSurgeNested<A> editMaxSurge() {
    return withNewMaxSurgeLike(getMaxSurge());
  }
  public RollingUpdateDeploymentFluent.MaxSurgeNested<A> editOrNewMaxSurge() {
    return withNewMaxSurgeLike(getMaxSurge() != null ? getMaxSurge(): new IntOrStringBuilder().build());
  }
  public RollingUpdateDeploymentFluent.MaxSurgeNested<A> editOrNewMaxSurgeLike(IntOrString item) {
    return withNewMaxSurgeLike(getMaxSurge() != null ? getMaxSurge(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public IntOrString buildMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public A withMaxUnavailable(IntOrString maxUnavailable) {
    _visitables.get("maxUnavailable").remove(this.maxUnavailable);
    if (maxUnavailable!=null){ this.maxUnavailable= new IntOrStringBuilder(maxUnavailable); _visitables.get("maxUnavailable").add(this.maxUnavailable);} else { this.maxUnavailable = null; _visitables.get("maxUnavailable").remove(this.maxUnavailable); } return (A) this;
  }
  public Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public A withNewMaxUnavailable(Object value) {
    return (A)withMaxUnavailable(new IntOrString(value));
  }
  public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> withNewMaxUnavailable() {
    return new RollingUpdateDeploymentFluentImpl.MaxUnavailableNestedImpl();
  }
  public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item) {
    return new RollingUpdateDeploymentFluentImpl.MaxUnavailableNestedImpl(item);
  }
  public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> editMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable());
  }
  public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): new IntOrStringBuilder().build());
  }
  public RollingUpdateDeploymentFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item) {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RollingUpdateDeploymentFluentImpl that = (RollingUpdateDeploymentFluentImpl) o;
    if (maxSurge != null ? !maxSurge.equals(that.maxSurge) :that.maxSurge != null) return false;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxSurge,  maxUnavailable,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (maxSurge != null) { sb.append("maxSurge:"); sb.append(maxSurge + ","); }
    if (maxUnavailable != null) { sb.append("maxUnavailable:"); sb.append(maxUnavailable + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MaxSurgeNestedImpl<N> extends IntOrStringFluentImpl<RollingUpdateDeploymentFluent.MaxSurgeNested<N>> implements RollingUpdateDeploymentFluent.MaxSurgeNested<N>,Nested<N>{
    MaxSurgeNestedImpl(IntOrString item) {
      this.builder = new IntOrStringBuilder(this, item);
    }
    MaxSurgeNestedImpl() {
      this.builder = new IntOrStringBuilder(this);
    }
    IntOrStringBuilder builder;
    public N and() {
      return (N) RollingUpdateDeploymentFluentImpl.this.withMaxSurge(builder.build());
    }
    public N endMaxSurge() {
      return and();
    }
    
  }
  class MaxUnavailableNestedImpl<N> extends IntOrStringFluentImpl<RollingUpdateDeploymentFluent.MaxUnavailableNested<N>> implements RollingUpdateDeploymentFluent.MaxUnavailableNested<N>,Nested<N>{
    MaxUnavailableNestedImpl(IntOrString item) {
      this.builder = new IntOrStringBuilder(this, item);
    }
    MaxUnavailableNestedImpl() {
      this.builder = new IntOrStringBuilder(this);
    }
    IntOrStringBuilder builder;
    public N and() {
      return (N) RollingUpdateDeploymentFluentImpl.this.withMaxUnavailable(builder.build());
    }
    public N endMaxUnavailable() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-extensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/RollingUpdateDeploymentFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.model.IntOrString;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RollingUpdateDeploymentFluentImpl<A extends RollingUpdateDeploymentFluent<A>> extends BaseFluent<A> implements RollingUpdateDeploymentFluent<A>{
  public RollingUpdateDeploymentFluentImpl() {
  }
  public RollingUpdateDeploymentFluentImpl(RollingUpdateDeployment instance) {
    if (instance != null) {
      this.withMaxSurge(instance.getMaxSurge());
      this.withMaxUnavailable(instance.getMaxUnavailable());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private IntOrStringBuilder maxSurge;
  private IntOrStringBuilder maxUnavailable;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMaxSurge instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxSurge() {
    return this.maxSurge!=null ?this.maxSurge.build():null;
  }
  public IntOrString buildMaxSurge() {
    return this.maxSurge!=null ?this.maxSurge.build():null;
  }
  public A withMaxSurge(IntOrString maxSurge) {
    _visitables.get("maxSurge").remove(this.maxSurge);
    if (maxSurge!=null){ this.maxSurge= new IntOrStringBuilder(maxSurge); _visitables.get("maxSurge").add(this.maxSurge);} else { this.maxSurge = null; _visitables.get("maxSurge").remove(this.maxSurge); } return (A) this;
  }
  public Boolean hasMaxSurge() {
    return this.maxSurge != null;
  }
  public A withNewMaxSurge(Object value) {
    return (A)withMaxSurge(new IntOrString(value));
  }
  public RollingUpdateDeploymentFluentImpl.MaxSurgeNested<A> withNewMaxSurge() {
    return new RollingUpdateDeploymentFluentImpl.MaxSurgeNestedImpl();
  }
  public RollingUpdateDeploymentFluentImpl.MaxSurgeNested<A> withNewMaxSurgeLike(IntOrString item) {
    return new RollingUpdateDeploymentFluentImpl.MaxSurgeNestedImpl(item);
  }
  public RollingUpdateDeploymentFluentImpl.MaxSurgeNested<A> editMaxSurge() {
    return withNewMaxSurgeLike(getMaxSurge());
  }
  public RollingUpdateDeploymentFluentImpl.MaxSurgeNested<A> editOrNewMaxSurge() {
    return withNewMaxSurgeLike(getMaxSurge() != null ? getMaxSurge(): new IntOrStringBuilder().build());
  }
  public RollingUpdateDeploymentFluentImpl.MaxSurgeNested<A> editOrNewMaxSurgeLike(IntOrString item) {
    return withNewMaxSurgeLike(getMaxSurge() != null ? getMaxSurge(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public IntOrString buildMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public A withMaxUnavailable(IntOrString maxUnavailable) {
    _visitables.get("maxUnavailable").remove(this.maxUnavailable);
    if (maxUnavailable!=null){ this.maxUnavailable= new IntOrStringBuilder(maxUnavailable); _visitables.get("maxUnavailable").add(this.maxUnavailable);} else { this.maxUnavailable = null; _visitables.get("maxUnavailable").remove(this.maxUnavailable); } return (A) this;
  }
  public Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public A withNewMaxUnavailable(Object value) {
    return (A)withMaxUnavailable(new IntOrString(value));
  }
  public RollingUpdateDeploymentFluentImpl.MaxUnavailableNested<A> withNewMaxUnavailable() {
    return new RollingUpdateDeploymentFluentImpl.MaxUnavailableNestedImpl();
  }
  public RollingUpdateDeploymentFluentImpl.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item) {
    return new RollingUpdateDeploymentFluentImpl.MaxUnavailableNestedImpl(item);
  }
  public RollingUpdateDeploymentFluentImpl.MaxUnavailableNested<A> editMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable());
  }
  public RollingUpdateDeploymentFluentImpl.MaxUnavailableNested<A> editOrNewMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): new IntOrStringBuilder().build());
  }
  public RollingUpdateDeploymentFluentImpl.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item) {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RollingUpdateDeploymentFluentImpl that = (RollingUpdateDeploymentFluentImpl) o;
    if (!java.util.Objects.equals(maxSurge, that.maxSurge)) return false;

    if (!java.util.Objects.equals(maxUnavailable, that.maxUnavailable)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxSurge,  maxUnavailable,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (maxSurge != null) { sb.append("maxSurge:"); sb.append(maxSurge + ","); }
    if (maxUnavailable != null) { sb.append("maxUnavailable:"); sb.append(maxUnavailable + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MaxSurgeNestedImpl<N> extends IntOrStringFluentImpl<RollingUpdateDeploymentFluentImpl.MaxSurgeNested<N>> implements RollingUpdateDeploymentFluentImpl.MaxSurgeNested<N>,Nested<N>{
    MaxSurgeNestedImpl(IntOrString item) {
      this.builder = new IntOrStringBuilder(this, item);
    }
    MaxSurgeNestedImpl() {
      this.builder = new IntOrStringBuilder(this);
    }
    IntOrStringBuilder builder;
    public N and() {
      return (N) RollingUpdateDeploymentFluentImpl.this.withMaxSurge(builder.build());
    }
    public N endMaxSurge() {
      return and();
    }
    
  }
  class MaxUnavailableNestedImpl<N> extends IntOrStringFluentImpl<RollingUpdateDeploymentFluentImpl.MaxUnavailableNested<N>> implements RollingUpdateDeploymentFluentImpl.MaxUnavailableNested<N>,Nested<N>{
    MaxUnavailableNestedImpl(IntOrString item) {
      this.builder = new IntOrStringBuilder(this, item);
    }
    MaxUnavailableNestedImpl() {
      this.builder = new IntOrStringBuilder(this);
    }
    IntOrStringBuilder builder;
    public N and() {
      return (N) RollingUpdateDeploymentFluentImpl.this.withMaxUnavailable(builder.build());
    }
    public N endMaxUnavailable() {
      return and();
    }
    
  }
  
}
